==> apache-streampipes-0.97.0-source-release.zip: apache-streampipes-0.97.0/streampipes-extensions/streampipes-connectors-opcua/src/main/java/org/apache/streampipes/extensions/connectors/opcua/config/OpcUaAdapterConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.extensions.connectors.opcua.config;

public class OpcUaAdapterConfig extends OpcUaConfig {

  private Integer pullIntervalMilliSeconds;
  private String incompleteEventStrategy;

  public Integer getPullIntervalMilliSeconds() {
    return pullIntervalMilliSeconds;
  }

  public void setPullIntervalMilliSeconds(Integer pullIntervalMilliSeconds) {
    this.pullIntervalMilliSeconds = pullIntervalMilliSeconds;
  }

  public boolean inPullMode() {
    return pullIntervalMilliSeconds != null;
  }

  public String getIncompleteEventStrategy() {
    return incompleteEventStrategy;
  }

  public void setIncompleteEventStrategy(String incompleteEventStrategy) {
    this.incompleteEventStrategy = incompleteEventStrategy;
  }
}

==> apache-streampipes-0.98.0-source-release.zip: apache-streampipes-0.98.0/streampipes-extensions/streampipes-connectors-opcua/src/main/java/org/apache/streampipes/extensions/connectors/opcua/config/OpcUaAdapterConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.extensions.connectors.opcua.config;

import org.apache.streampipes.extensions.connectors.opcua.utils.OpcUaNamingStrategy;

public class OpcUaAdapterConfig extends OpcUaConfig {

  private Integer pullIntervalMilliSeconds;
  private String incompleteEventStrategy;
  private OpcUaNamingStrategy namingStrategy;

  public Integer getPullIntervalMilliSeconds() {
    return pullIntervalMilliSeconds;
  }

  public void setPullIntervalMilliSeconds(Integer pullIntervalMilliSeconds) {
    this.pullIntervalMilliSeconds = pullIntervalMilliSeconds;
  }

  public boolean inPullMode() {
    return pullIntervalMilliSeconds != null;
  }

  public String getIncompleteEventStrategy() {
    return incompleteEventStrategy;
  }

  public void setIncompleteEventStrategy(String incompleteEventStrategy) {
    this.incompleteEventStrategy = incompleteEventStrategy;
  }

  public OpcUaNamingStrategy getNamingStrategy() {
    return namingStrategy;
  }

  public void setNamingStrategy(OpcUaNamingStrategy namingStrategy) {
    this.namingStrategy = namingStrategy;
  }
}
